********************************************************************************
Citing
********************************************************************************

If you use **COMPAS CEM** for a project or research, please consider citing our journal paper:

.. code-block:: latex

    @article{pastrana_constrainedformfinding_2022,
             title = {Constrained {Form}-{Finding} of {Tension}–{Compression} {Structures} using {Automatic} {Differentiation}},
             author = {Pastrana, Rafael and Ohlbrock, Patrick Ole and Oberbichler, Thomas and D’Acunto, Pierluigi and Parascho, Stefana},
             journal = {Computer-Aided Design},
             doi = {10.1016/j.cad.2022.103435},
             volume = {155},
             issn = {0010-4485},
             url = {https://www.sciencedirect.com/science/article/pii/S0010448522001683},
             month = feb,
             year = {2022}}

And the code repository:

.. code-block:: latex

    @software{compas_cem,
        title={{COMPAS~CEM}: The {Combinatorial Equilibrium Modeling} framework for {COMPAS}},
        author={Pastrana, Rafael and
                Ohlbrock, Patrick Ole and
                D'Acunto, Pierluigi and
                Parascho, Stefana},
        year={2021},
        doi={10.5281/zenodo.5705740},
        url={https://arpastrana.github.io/compas\_cem}}


Authors
=======

* Rafael Pastrana <arpastrana@princeton> `@arpastrana <https://github.com/arpastrana>`_
* Ole Ohlbrock <ohlbrock@arch.ethz.ch> `@OleOhlbrock <https://github.com/OleOhlbrock>`_
* Pierluigi D'Acunto <pierluigidacunto@tum.de> `@pierluigidacunto <https://github.com/pierluigidacunto>`_
* Stefana Parascho <stefana.parascho@epfl.ch> `@stefanaparascho <https://github.com/stefanaparascho>`_
